@@ -2,10 +2,10 @@
 #################################################################
 #  Copyright notice
 #
-#  (c) 2012 Jérôme Schneider <mail@jeromeschneider.fr>
+#  (c) 2013 Jérôme Schneider <mail@jeromeschneider.fr>
 #  All rights reserved
 #
-#  http://baikal.codr.fr
+#  http://baikal-server.com
 #
 #  This script is part of the Baïkal Server project. The Baïkal
 #  Server project is free software; you can redistribute it
@@ -34,8 +34,12 @@ class Initialize extends \Flake\Core\Controller {
 	
 	public function execute() {
 		# Assert that /Specific is writable
+
 		if(!file_exists(PROJECT_PATH_SPECIFIC) || !is_dir(PROJECT_PATH_SPECIFIC) || !is_writable(PROJECT_PATH_SPECIFIC)) {
-			throw new \Exception("Specific/ dir is readonly. Baïkal Admin requires write permissions on this dir.");
+			$message = "<h1>Error - Insufficient  permissions on the <span style='background-color: yellow;'>Specific/</span> folder</h1><p>";
+			$message .= "<p>In order to work properly, Baïkal needs to have write permissions in the <strong>Specific/</strong> folder.</p>";
+
+			die($message);
 		}
 
 		$this->createHtaccessFilesIfNeeded();
