@@ -2,10 +2,10 @@
 #################################################################
 #  Copyright notice
 #
-#  (c) 2012 Jérôme Schneider <mail@jeromeschneider.fr>
+#  (c) 2013 Jérôme Schneider <mail@jeromeschneider.fr>
 #  All rights reserved
 #
-#  http://baikal.codr.fr
+#  http://baikal-server.com
 #
 #  This script is part of the Baïkal Server project. The Baïkal
 #  Server project is free software; you can redistribute it
@@ -34,13 +34,9 @@ class Framework extends \Flake\Core\Framework {
 		\Baikal\Framework::bootstrap();
 		\Formal\Framework::bootstrap();
 
-		# Registering BaikalAdmin classloader
-		require_once(BAIKALADMIN_PATH_ROOT . '/Core/ClassLoader.php');
-		\BaikalAdmin\Core\ClassLoader::register();
-		
 		$GLOBALS["ROUTER"]::setURIPath("admin/");
 
 		# Include BaikalAdmin Framework config
 		require_once(BAIKALADMIN_PATH_ROOT . "config.php");
 	}
-}
\ No newline at end of file
+}
