@@ -2,7 +2,7 @@
 #################################################################
 #  Copyright notice
 #
-#  (c) 2012 Jérôme Schneider <mail@jeromeschneider.fr>
+#  (c) 2013 Jérôme Schneider <mail@jeromeschneider.fr>
 #  All rights reserved
 #
 #  http://formal.codr.fr
@@ -30,8 +30,6 @@ class Framework extends \Flake\Core\Framework {
 	
 	public static function bootstrap() {
 		define("FORMAL_PATH_ROOT", PROJECT_PATH_ROOT . "Core/Frameworks/Formal/");
-		
-		require_once(FORMAL_PATH_ROOT . 'Core/ClassLoader.php');
-		\Formal\Core\ClassLoader::register();		
+
 	}
-}
\ No newline at end of file
+}
