@@ -24,7 +24,9 @@
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
 
-ini_set("display_errors", 1);
+ini_set("session.cookie_httponly", 1);
+ini_set("display_errors", 0);
+ini_set("log_errors", 1);
 error_reporting(E_ALL);
 
 define("BAIKAL_CONTEXT", TRUE);
@@ -39,8 +41,13 @@ if(file_exists(dirname(dirname(getcwd())) . "/Core")) {
 	define("PROJECT_PATH_ROOT", dirname(dirname(dirname(getcwd()))) . "/");	# ../../../
 }
 
-# Bootstraping Flake
+if(!file_exists(PROJECT_PATH_ROOT . 'vendor/')) {
+	die('<h1>Incomplete installation</h1><p>Ba&iuml;kal dependencies have not been installed. Please, execute "<strong>composer install</strong>" in the folder where you installed Ba&iuml;kal.');
+}
+
 require PROJECT_PATH_ROOT . "vendor/autoload.php";
+
+# Bootstraping Flake
 \Flake\Framework::bootstrap();
 
 # Bootstrap BaikalAdmin
